@@ -1,4 +1,4 @@
-#' Save a Canvas to an External Device.
+#' Save a Canvas to an External Device
 #'
 #' @description This function is a wrapper around \code{ggplot2::ggsave}. It provides a suggested export with square dimensions for a canvas created using the \code{aRtsy} package.
 #'
@@ -13,11 +13,12 @@
 #' @return No return value, called for saving plots.
 #'
 #' @author Koen Derks, \email{koen-derks@hotmail.com}
-#' 
+#'
 #' @keywords canvas save
-#' 
+#'
 #' @export
 
 saveCanvas <- function(plot, filename, width = 7, height = 7, dpi = 300) {
-  ggplot2::ggsave(plot = plot, filename = filename, width = width, height = height, units = 'cm', dpi = dpi)
-}
\ No newline at end of file
+  plot <- plot + ggplot2::theme(plot.margin = ggplot2::unit(rep(-1.25, 4), "lines"))
+  ggplot2::ggsave(plot = plot, filename = filename, width = width, height = height, units = "cm", dpi = dpi)
+}
